@@ -2,7 +2,7 @@ package Test2::Event::Ok;
 use strict;
 use warnings;
 
-our $VERSION = '1.302037';
+our $VERSION = '1.302040';
 
 
 BEGIN { require Test2::Event; our @ISA = qw(Test2::Event) }
@@ -84,7 +84,6 @@ or:
         'Ok',
         pass => $bool,
         name => $name,
-        diag => \@diag
     );
 
 =head1 ACCESSORS
@@ -100,10 +99,6 @@ reduced down to 1 or 0).
 
 Name of the test.
 
-=item $diag = $e->diag
-
-An arrayref full of diagnostics strings to print in the event of a failure.
-
 =item $b = $e->effective_pass
 
 This is the true/false value of the test after TODO and similar modifiers are
